var express = require("express");
var cors = require("cors");
var userAuth = require("./middleware/userAuth");
var app = express();
const port = 5000;
require("./utils/dbfunctions").connect();
const rateLimit = require('express-rate-limit');
const xss = require('xss-clean');
const helmet = require('helmet');

const limiter = rateLimit({
	windowMs: 15 * 60 * 1000, // 15 minutes
	limit: 100, // Limit each IP to 100 requests per `window` (here, per 15 minutes).
	standardHeaders: 'draft-7', // draft-6: `RateLimit-*` headers; draft-7: combined `RateLimit` header
	legacyHeaders: false, // Disable the `X-RateLimit-*` headers.
	// store: ... , // Use an external store for consistency across multiple server instances.
  message: "you have exceed the number of request"
});

//MiddleWares
app.use(cors());
app.use(express.urlencoded({ extended: false }));
app.use(express.json());
app.use(express.static("public"));

app.use(helmet());

// Apply the rate limiting middleware to all requests.
app.use(limiter);

// make sure this comes before any routes
app.use(xss());

// Routes

// Users
const login = require("./apis/users/login");
const selectUser = require("./apis/users/selectUser");
const createUser = require("./apis/users/createUser");
const updateUser = require("./apis/users/updateUser");
const deleteUser = require("./apis/users/deleteUser");
const changePass = require("./apis/users/userPasswordReset");

// Routes Middleware

// User
app.use("/api/users", login);
app.use("/api/users", userAuth, selectUser);
app.use("/api/users",userAuth, createUser);
app.use("/api/users",userAuth, updateUser);
app.use("/api/users",userAuth, deleteUser);
app.use("/api/password",userAuth, changePass);

app.get("/", userAuth, (req, res) => {
  res.send("Hello from, fine");
});

//Server Listining
app.listen(port, "0.0.0.0", () => {
  console.log(`AD listening at http://localhost:${port}`);
});
